| Title: | Graphical Check for Proportional Odds Assumption |
|---|---|
| Description: | Implements the method described at the UCLA Statistical Consulting site <https://stats.idre.ucla.edu/r/dae/ordinal-logistic-regression/> for checking if the proportional odds assumption holds for a cumulative logit model. |
| Authors: | Melissa Wong [aut, cre] (ORCID: <https://orcid.org/0000-0002-2973-6279>) |
| Maintainer: | Melissa Wong <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.1 |
| Built: | 2026-05-23 08:11:17 UTC |
| Source: | https://github.com/melissa-wong/pomcheckr |
A dataset used in the UCLA Statistical Consulting Survey Analysis in R guide https://stats.idre.ucla.edu/r/seminars/survey-data-analysis-with-r/
nhanesnhanes
A data frame with 9756 rows and 16 variables:
Respondent sequence number
Age in years at screening
Gender
Marital status
Education level - Adults 20+
Masked variance pseudo-PSU
Masked variance pseudo-stratum
Full sample 2 year interview weight
Gender
How many days feel anxious
SP donated blood in the past 12 months
General health condition
Minutes moderate-intensity work
Minutes moderate recreational activities
Moderate recreational activities
Minutes sedentary activity
https://wwwn.cdc.gov/nchs/nhanes/Search/DataPage.aspx?Component=Demographics&CycleBeginYear=2011
A dataset used in the UCLA Statistical Consulting Ordinal Logistic Regression Example https://stats.idre.ucla.edu/r/dae/ordinal-logistic-regression/
ologitologit
A data frame with 400 rows and 4 variables:
Likelihood of applying to graduate school
Indicator for whether at least 1 parent has a graduate degree
Indicator for whether undergraduate institution is public or private
Student's grade point average
https://stats.idre.ucla.edu/stat/data/ologit.dta
Generates the plots described in https://stats.idre.ucla.edu/r/dae/ordinal-logistic-regression/ for checking if the proportional odds assumption holds for a cumulative logit model.
## S3 method for class 'pomcheck' plot(x, legend.position = "none", ...)## S3 method for class 'pomcheck' plot(x, legend.position = "none", ...)
x |
a pomcheck object |
legend.position |
the position of legends ("none", "left", "right", "bottom", "top", or two-element numeric vector) |
... |
currently unused |
None
plot(pomcheck(Species ~ Sepal.Width, iris))plot(pomcheck(Species ~ Sepal.Width, iris))
Implements the method described in https://stats.idre.ucla.edu/r/dae/ordinal-logistic-regression/ for checking if the proportional odds assumption holds for a cumulative logit model.
pomcheck(object, ...) ## Default S3 method: pomcheck(object, x, data, ...) ## S3 method for class 'formula' pomcheck(formula, data, ...)pomcheck(object, ...) ## Default S3 method: pomcheck(object, x, data, ...) ## S3 method for class 'formula' pomcheck(formula, data, ...)
object |
character string for response |
... |
currently unused |
x |
vector of character string(s) for explanatory variable(s) |
data |
data frame containing the variables |
formula |
formula of the form y ~ x1 + x2 + ... |
an object of class 'pomcheck'
default: default
formula: supports formula specification
pomcheck(Species ~ Sepal.Length, iris) pomcheck(Species ~ Sepal.Length + Sepal.Width, iris) pomcheck(object="Species", x="Sepal.Length", iris) pomcheck(object="Species", x=c("Sepal.Length", "Sepal.Width"), iris)pomcheck(Species ~ Sepal.Length, iris) pomcheck(Species ~ Sepal.Length + Sepal.Width, iris) pomcheck(object="Species", x="Sepal.Length", iris) pomcheck(object="Species", x=c("Sepal.Length", "Sepal.Width"), iris)